## ------------------------------------------------
## Title  : main.r
## Authors: Oka and Qu 
## Date   : 04/28/2010
## Updated: 01/28/2013
## ------------------------------------------------

## Note: 
## This code is the main file used to implement the methods developed in
## "Estimating Structural Changes in Regression Quantiles."
## Please be advised that this code uses the R-package, quantreg,
## developed by Roger Koenker. If it is not yet installed,  
## then type the following command in R: 
## install.packages('quantreg')

## clear all existing objects
rm(list=ls(all=TRUE))

## library and source files
library(quantreg)
source('quant-chg.r')


##You need to change the following two lines to load your
##refer to app1-gdp-growth.R or app2-drunk-driving.R for examples
source('panel.dgp.n01.r')
DATA = panel.dgp.n01(2, 100, v.date = 50, loc.size = 8)

y    = as.matrix(DATA$y) #dependent variable; as a column
x    = as.matrix(DATA$x) #regressors;as a matrix; the j-th column corresponds to the jth regressor
				 #a constant will be automatically included

#specify the number of entities for a given t (i.e., the size of the cross-section)
N.size = 2

##specify the qunatiles of interest
vec.tau = seq(0.20, 0.80, 0.10)


## The interval of quantiles to be analyzed, needed for implementing the DQ test
## The default here is determined by the upper and lower limit of vec.tau
q.L   = min(vec.tau) 
q.R   = max(vec.tau)

## Global varible for implementing the DQ test. Set d.Sym=TRUE if the trimming parameter
## trimming parameter for vec.tau is symmetric: i.e, q.L = (1 - q.R); 
## Otherwise, set d.Sym=FALSE
d.Sym = TRUE

## If d.Sym = FALSE, then the critical values needs to be obtained via simulations.
## Then, you need to set d.Sim = TRUE.
## The simulation takes a while (say 20 minutes) depending on the computer you use.  
d.Sim = FALSE


## the maximum number of breaks allowed
m.max = 2

## the signifance level for sequenatial testing
## 1, 2 or 3 for 10%, 5% or 1%, respectively
v.a = 2 

## the significance level for the confidence intervals of
## estimated break dates.
## 1 or 2 for 90% and 95%, respectively.
v.b = 2

## The trimming proportion for estimating the break dates 
##(used to exclude the boundaries of the sample)
## Note: tirm.e has no effect on testing
trim.e = 0.05 

## your time index
## This affects only the output, not estimation or testing
vec.time = seq(1901, 2000, length = 100)



#---------------------------------------------
## You should not have to modify the following
#---------------------------------------------

## global variable (Do not change)
eps = .Machine$double.eps ^ (2/3) 
options(warn=-1)

## ====== Main Analysis ======
rq.break(y, x, vec.tau, N.size, trim.e, q.L, q.R, vec.time, m.max, v.a, v.b)

